@@ -1,5 +1,4 @@
 /**
- * @licence app begin@
  * Copyright (C) 2015  Advanced Driver Information Technology.
  * This code is developed by Advanced Driver Information Technology.
  * Copyright of Advanced Driver Information Technology, Bosch and DENSO.
@@ -18,7 +17,6 @@
  *
  * \file dlt-control-common.c
  * For further information see http://www.genivi.org/.
- * @licence end@
  */
 
 /*******************************************************************************
@@ -83,7 +81,7 @@
 static int (*response_analyzer_cb)(char *, void *, int);
 
 static pthread_t daemon_connect_thread;
-static DltClient client;
+static DltClient g_client;
 static int callback_return = -1;
 static pthread_mutex_t answer_lock = PTHREAD_MUTEX_INITIALIZER;
 static pthread_cond_t answer_cond = PTHREAD_COND_INITIALIZER;
@@ -426,7 +424,7 @@ static int dlt_control_init_connection(DltClient *client, void *cb)
     int (*callback)(DltMessage *message, void *data) = cb;
 
     if (!cb || !client) {
-        pr_error("%s Invalid parameters (%p, %p)\n", __func__, client, cb);
+        pr_error("%s: Invalid parameters\n", __func__);
         return -1;
     }
 
@@ -466,7 +464,7 @@ static int dlt_control_init_connection(DltClient *client, void *cb)
 static void *dlt_control_listen_to_daemon(void *data)
 {
     pr_verbose("Ready to receive DLT answers.\n");
-    dlt_client_main_loop(&client, NULL, get_verbosity());
+    dlt_client_main_loop(&g_client, NULL, get_verbosity());
     return data;
 }
 
@@ -483,7 +481,7 @@ static void *dlt_control_listen_to_daemon(void *data)
  * New values are signaled using a dedicated condition variable.
  *
  * @param message The DLT answer
- * @data Unused
+ * @param data Unused
  *
  * @return The analyzer return value or -1 on early errors.
  */
@@ -543,7 +541,7 @@ int dlt_control_send_message(DltControlMsgBody *body, int timeout)
     DltMessage *msg = NULL;
 
     if (!body) {
-        pr_error("Invalid input (%p).\n", body);
+        pr_error("%s: Invalid input.\n", __func__);
         return -1;
     }
 
@@ -567,7 +565,7 @@ int dlt_control_send_message(DltControlMsgBody *body, int timeout)
     /* Re-init the return value */
     callback_return = -1;
 
-    if (dlt_control_send_message_to_socket(client.sock, msg) != 0) {
+    if (dlt_control_send_message_to_socket(g_client.sock, msg) != 0) {
         pr_error("Sending message to daemon failed\n");
         free(msg);
         return -1;
@@ -603,7 +601,7 @@ int dlt_control_init(int (*response_analyzer)(char *, void *, int),
                      int verbosity)
 {
     if (!response_analyzer || !ecuid) {
-        pr_error("Invalid input (%p %p).\n", response_analyzer, ecuid);
+        pr_error("%s: Invalid input.\n", __func__);
         return -1;
     }
 
@@ -611,9 +609,9 @@ int dlt_control_init(int (*response_analyzer)(char *, void *, int),
     set_ecuid(ecuid);
     set_verbosity(verbosity);
 
-    if (dlt_control_init_connection(&client, dlt_control_callback) != 0) {
+    if (dlt_control_init_connection(&g_client, dlt_control_callback) != 0) {
         pr_error("Connection initialization failed\n");
-        dlt_client_cleanup(&client, get_verbosity());
+        dlt_client_cleanup(&g_client, get_verbosity());
         return -1;
     }
 
@@ -640,5 +638,5 @@ int dlt_control_deinit(void)
     /* Stopping the listener thread */
     pthread_cancel(daemon_connect_thread);
     /* Closing the socket */
-    return dlt_client_cleanup(&client, get_verbosity());
+    return dlt_client_cleanup(&g_client, get_verbosity());
 }
