@@ -71,9 +71,7 @@
 #include <syslog.h>
 #include <errno.h>
 #include <unistd.h>
-#include <fcntl.h>
 
-#include <sys/types.h>  /* send() */
 #include <sys/socket.h> /* send() */
 
 #include "dlt_types.h"
@@ -145,7 +143,13 @@ int dlt_daemon_load_runtime_configuration(DltDaemon *daemon, const char *runtime
 {
     int append_length = 0;
 
-    if ((daemon == NULL) || (runtime_directory == NULL))
+    if (daemon == NULL)
+        return DLT_RETURN_ERROR;
+
+    /* Default */
+    daemon->mode = DLT_USER_MODE_EXTERNAL;
+
+    if (runtime_directory == NULL)
         return DLT_RETURN_ERROR;
 
     /* prepare filenames for configuration */
@@ -225,8 +229,6 @@ int dlt_daemon_init(DltDaemon *daemon,
 
     daemon->runtime_context_cfg_loaded = 0;
 
-    daemon->mode = DLT_USER_MODE_EXTERNAL;
-
     daemon->connectionState = 0; /* no logger connected */
 
     daemon->state = DLT_DAEMON_STATE_INIT; /* initial logging state */
@@ -373,8 +375,6 @@ int dlt_daemon_applications_clear(DltDaemon *daemon, char *ecu, int verbose)
             user_list->applications[i].application_description = NULL;
         }
 
-
-
     if (user_list->applications != NULL)
         free(user_list->applications);
 
@@ -479,12 +479,8 @@ DltDaemonApplication *dlt_daemon_application_add(DltDaemon *daemon,
         application->application_description = malloc(strlen(description) + 1);
 
         if (application->application_description) {
-            strncpy(application->application_description,
-                    description,
-                    strlen(description));
-            application->application_description[strlen(description)] = '\0';
-        }
-        else {
+            memcpy(application->application_description, description, strlen(description) + 1);
+        } else {
             dlt_log(LOG_ERR, "Cannot allocate memory to store application description\n");
             free(application);
             return (DltDaemonApplication *)NULL;
@@ -872,8 +868,7 @@ DltDaemonContext *dlt_daemon_context_add(DltDaemon *daemon,
         context->context_description = malloc(strlen(description) + 1);
 
         if (context->context_description) {
-            strncpy(context->context_description, description, strlen(description));
-            context->context_description[strlen(description)] = '\0';
+            memcpy(context->context_description, description, strlen(description) + 1);
         }
     }
 
@@ -1060,8 +1055,6 @@ int dlt_daemon_contexts_clear(DltDaemon *daemon, char *ecu, int verbose)
             users->contexts[i].context_description = NULL;
         }
 
-
-
     if (users->contexts) {
         free(users->contexts);
         users->contexts = NULL;
@@ -1496,12 +1489,11 @@ void dlt_daemon_user_send_default_update(DltDaemon *daemon, int verbose)
         if (context != NULL) {
             if ((context->log_level == DLT_LOG_DEFAULT) ||
                 (context->trace_status == DLT_TRACE_STATUS_DEFAULT)) {
-                if (context->user_handle >= DLT_FD_MINIMUM) {
+                if (context->user_handle >= DLT_FD_MINIMUM)
                     if (dlt_daemon_user_send_log_level(daemon,
                                                        context,
                                                        verbose) == -1)
                         dlt_vlog(LOG_WARNING, "Cannot update default of %.4s:%.4s\n", context->apid, context->ctid);
-                }
             }
         }
     }
@@ -1601,10 +1593,9 @@ void dlt_daemon_user_send_all_log_state(DltDaemon *daemon, int verbose)
         app = &(user_list->applications[count]);
 
         if (app != NULL) {
-            if (app->user_handle >= DLT_FD_MINIMUM) {
+            if (app->user_handle >= DLT_FD_MINIMUM)
                 if (dlt_daemon_user_send_log_state(daemon, app, verbose) == -1)
                     dlt_vlog(LOG_WARNING, "Cannot send log state to Apid: %.4s, PID: %d\n", app->apid, app->pid);
-            }
         }
     }
 }
