@@ -54,7 +54,8 @@
 int dlt_logstorage_prepare_on_msg(DltLogStorageFilterConfig *config,
                                   DltLogStorageUserConfig *file_config,
                                   char *dev_path,
-                                  int log_msg_size);
+                                  int log_msg_size,
+                                  char *newest_file);
 int dlt_logstorage_write_on_msg(DltLogStorageFilterConfig *config,
                                 DltLogStorageUserConfig *file_config,
                                 char *dev_path,
@@ -76,7 +77,8 @@ int dlt_logstorage_sync_on_msg(DltLogStorageFilterConfig *config,
 int dlt_logstorage_prepare_msg_cache(DltLogStorageFilterConfig *config,
                                      DltLogStorageUserConfig *file_config,
                                      char *dev_path,
-                                     int log_msg_size);
+                                     int log_msg_size,
+                                     char *newest_file);
 
 int dlt_logstorage_write_msg_cache(DltLogStorageFilterConfig *config,
                                    DltLogStorageUserConfig *file_config,
