@@ -88,7 +88,8 @@ unsigned int dlt_offline_trace_storage_dir_info(char *path, char *file_name, cha
         int len = 0;
         len = strlen(file_name);
 
-        if ((strncmp(files[i]->d_name, file_name, len) == 0) && (files[i]->d_name[len] == '.')) {
+        if ((strncmp(files[i]->d_name, file_name, len) == 0) &&
+            (files[i]->d_name[len] == DLT_OFFLINETRACE_FILENAME_INDEX_DELI[0])) {
             num++;
 
             if ((tmp_old == NULL) || (strlen(tmp_old) >= strlen(files[i]->d_name))) {
@@ -98,19 +99,16 @@ unsigned int dlt_offline_trace_storage_dir_info(char *path, char *file_name, cha
                 else if (strlen(tmp_old) > strlen(files[i]->d_name))
                     tmp_old = files[i]->d_name;
                 else /* filename is equal, do a string compare */
-                    if (strcmp(tmp_old, files[i]->d_name) > 0)
-                        tmp_old = files[i]->d_name;
+                if (strcmp(tmp_old, files[i]->d_name) > 0)
+                    tmp_old = files[i]->d_name;
             }
 
             if ((tmp_new == NULL) || (strlen(tmp_new) <= strlen(files[i]->d_name))) {
-                if (tmp_new == NULL) {
+                if (tmp_new == NULL)
                     tmp_new = files[i]->d_name;
-                }
                 /* when file name is longer, it is younger */
                 else if (strlen(tmp_new) < strlen(files[i]->d_name))
-                {
                     tmp_new = files[i]->d_name;
-                }
                 else if (strcmp(tmp_new, files[i]->d_name) < 0)
                     tmp_new = files[i]->d_name;
             }
@@ -118,14 +116,14 @@ unsigned int dlt_offline_trace_storage_dir_info(char *path, char *file_name, cha
     }
 
     if (num > 0) {
-        if (tmp_old != NULL) {
-            if (strlen(tmp_old) < DLT_OFFLINETRACE_FILENAME_MAX_SIZE)
-                strncpy(oldest, tmp_old, DLT_OFFLINETRACE_FILENAME_MAX_SIZE);
+        if ((tmp_old != NULL) && (strlen(tmp_old) < NAME_MAX)) {
+            strncpy(oldest, tmp_old, NAME_MAX);
+            oldest[NAME_MAX] = '\0';
         }
 
-        if (tmp_new != NULL) {
-            if (strlen(tmp_old) < DLT_OFFLINETRACE_FILENAME_MAX_SIZE)
-                strncpy(newest, tmp_new, DLT_OFFLINETRACE_FILENAME_MAX_SIZE);
+        if ((tmp_new != NULL) && (strlen(tmp_old) < NAME_MAX)) {
+            strncpy(newest, tmp_new, NAME_MAX);
+            oldest[NAME_MAX] = '\0';
         }
     }
 
@@ -138,22 +136,25 @@ unsigned int dlt_offline_trace_storage_dir_info(char *path, char *file_name, cha
     return num;
 }
 
-void dlt_offline_trace_file_name(char *log_file_name, char *name, unsigned int idx)
+void dlt_offline_trace_file_name(char *log_file_name, size_t length,
+                                 char *name, unsigned int idx)
 {
     char file_index[11]; /* UINT_MAX = 4294967295 -> 10 digits */
     snprintf(file_index, sizeof(file_index), "%010u", idx);
 
     /* create log file name */
-    memset(log_file_name, 0, DLT_OFFLINETRACE_FILENAME_MAX_SIZE * sizeof(char));
-    strncat(log_file_name, name, sizeof(log_file_name) - strlen(log_file_name) - 1);
-    strncat(log_file_name, DLT_OFFLINETRACE_FILENAME_DELI, sizeof(log_file_name) - strlen(log_file_name) - 1);
-    strncat(log_file_name, file_index, sizeof(log_file_name) - strlen(log_file_name) - 1);
-    strncat(log_file_name, DLT_OFFLINETRACE_FILENAME_EXT, sizeof(log_file_name) - strlen(log_file_name) - 1);
+    memset(log_file_name, 0, length * sizeof(char));
+    strncat(log_file_name, name, length - strlen(log_file_name) - 1);
+    strncat(log_file_name, DLT_OFFLINETRACE_FILENAME_INDEX_DELI,
+            length - strlen(log_file_name) - 1);
+    strncat(log_file_name, file_index, length - strlen(log_file_name) - 1);
+    strncat(log_file_name, DLT_OFFLINETRACE_FILENAME_EXT,
+            length - strlen(log_file_name) - 1);
 }
 
 unsigned int dlt_offline_trace_get_idx_of_log_file(char *file)
 {
-    const char d[2] = ".";
+    const char d[2] = DLT_OFFLINETRACE_FILENAME_INDEX_DELI;
     char *token;
     unsigned int idx = 0;
 
@@ -177,34 +178,50 @@ DltReturnValue dlt_offline_trace_create_new_file(DltOfflineTrace *trace)
 {
     time_t t;
     struct tm tmp;
-    char outstr[200];
-    char newest[DLT_OFFLINETRACE_FILENAME_MAX_SIZE] = { 0 };
-    char oldest[DLT_OFFLINETRACE_FILENAME_MAX_SIZE] = { 0 };
+    char file_path[PATH_MAX + 1];
     unsigned int idx = 0;
+    int ret = 0;
 
     /* set filename */
     if (trace->filenameTimestampBased) {
-        int ret = 0;
+        /* timestamp format: "yyyymmdd_hhmmss" */
+        char timestamp[16];
         t = time(NULL);
+        tzset();
         localtime_r(&t, &tmp);
 
-        strftime(outstr, sizeof(outstr), "%Y%m%d_%H%M%S", &tmp);
+        strftime(timestamp, sizeof(timestamp), "%Y%m%d_%H%M%S", &tmp);
 
-        ret = snprintf(trace->filename, NAME_MAX, "%s/dlt_offlinetrace_%s.dlt", trace->directory, outstr);
+        ret = snprintf(trace->filename, sizeof(trace->filename), "%s%s%s%s",
+                       DLT_OFFLINETRACE_FILENAME_BASE,
+                       DLT_OFFLINETRACE_FILENAME_TIMESTAMP_DELI, timestamp,
+                       DLT_OFFLINETRACE_FILENAME_EXT);
 
-        if ((ret < 0) || (ret >= NAME_MAX)) {
+        if ((ret < 0) || ((size_t)ret >= (int)sizeof(trace->filename))) {
             printf("dlt_offlinetrace filename cannot be concatenated\n");
             return DLT_RETURN_ERROR;
         }
+
+        ret = snprintf(file_path, sizeof(file_path), "%s/%s",
+                       trace->directory, trace->filename);
+
+        if ((ret < 0) || ((size_t)ret >= (int)sizeof(file_path))) {
+            printf("dlt_offlinetrace file path cannot be concatenated\n");
+            return DLT_RETURN_ERROR;
+        }
     }
     else {
-        int ret = 0;
+        char newest[NAME_MAX + 1] = { 0 };
+        char oldest[NAME_MAX + 1] = { 0 };
         /* targeting newest file, ignoring number of files in dir returned */
-        dlt_offline_trace_storage_dir_info(trace->directory, DLT_OFFLINETRACE_FILENAME_BASE, newest, oldest);
+        dlt_offline_trace_storage_dir_info(trace->directory,
+                                           DLT_OFFLINETRACE_FILENAME_BASE, newest, oldest);
         idx = dlt_offline_trace_get_idx_of_log_file(newest) + 1;
 
-        dlt_offline_trace_file_name(outstr, DLT_OFFLINETRACE_FILENAME_BASE, idx);
-        ret = snprintf(trace->filename, NAME_MAX, "%s/%s", trace->directory, outstr);
+        dlt_offline_trace_file_name(trace->filename, sizeof(trace->filename),
+                                    DLT_OFFLINETRACE_FILENAME_BASE, idx);
+        ret = snprintf(file_path, sizeof(file_path), "%s/%s",
+                       trace->directory, trace->filename);
 
         if ((ret < 0) || (ret >= NAME_MAX)) {
             printf("filename cannot be concatenated\n");
@@ -213,27 +230,31 @@ DltReturnValue dlt_offline_trace_create_new_file(DltOfflineTrace *trace)
     }
 
     /* open DLT output file */
-    trace->ohandle = open(trace->filename, O_WRONLY | O_CREAT, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH); /* mode: wb */
+    trace->ohandle = open(file_path, O_WRONLY | O_CREAT, S_IRUSR | S_IWUSR |
+                          S_IRGRP | S_IROTH); /* mode: wb */
 
     if (trace->ohandle == -1) {
         /* trace file cannot be opened */
-        printf("Offline trace file %s cannot be created\n", trace->filename);
+        printf("Offline trace file %s cannot be created\n", file_path);
         return DLT_RETURN_ERROR;
     } /* if */
 
     return DLT_RETURN_OK; /* OK */
 }
 
-unsigned long dlt_offline_trace_get_total_size(DltOfflineTrace *trace)
+ssize_t dlt_offline_trace_get_total_size(DltOfflineTrace *trace)
 {
     struct dirent *dp;
-    char filename[256];
-    unsigned long size = 0;
+    char filename[PATH_MAX + 1];
+    ssize_t size = 0;
     struct stat status;
 
     /* go through all dlt files in directory */
     DIR *dir = opendir(trace->directory);
 
+    if (!dir)
+        return -1;
+
     while ((dp = readdir(dir)) != NULL)
         if (strstr(dp->d_name, DLT_OFFLINETRACE_FILENAME_BASE)) {
             int res = snprintf(filename, sizeof(filename), "%s/%s", trace->directory, dp->d_name);
@@ -276,7 +297,7 @@ int dlt_offline_trace_delete_oldest_file(DltOfflineTrace *trace)
     DIR *dir = opendir(trace->directory);
 
     while ((dp = readdir(dir)) != NULL)
-        if (strstr(dp->d_name, DLT_OFFLINETRACE_FILENAME_TO_COMPARE)) {
+        if (strstr(dp->d_name, DLT_OFFLINETRACE_FILENAME_BASE)) {
             int res = snprintf(filename, sizeof(filename), "%s/%s", trace->directory, dp->d_name);
 
             /* if the total length of the string is greater than the buffer, silently forget it. */
@@ -333,12 +354,17 @@ DltReturnValue dlt_offline_trace_check_size(DltOfflineTrace *trace)
         return DLT_RETURN_ERROR;
     }
 
+    ssize_t s = 0;
+
     /* check size of complete offline trace */
-    while ((int)dlt_offline_trace_get_total_size(trace) > (trace->maxSize - trace->fileSize))
+    while ((s = dlt_offline_trace_get_total_size(trace)) > (trace->maxSize - trace->fileSize))
         /* remove oldest files as long as new file will not fit in completely into complete offline trace */
         if (dlt_offline_trace_delete_oldest_file(trace) < 0)
             return DLT_RETURN_ERROR;
 
+    if (s == -1)
+        return DLT_RETURN_ERROR;
+
     return DLT_RETURN_OK; /* OK */
 }
 
